﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using Infragistics.Win.FormattedLinkLabel;

namespace ExampleChart
{
    public partial class frmLayoutPanel : Form
    {
        Random rand = new Random((int)DateTime.Now.Ticks);

        public frmLayoutPanel()
        {
            InitializeComponent();
            InitChart();
        }

        private void InitChart()
        {
            Size preferredSize = new System.Drawing.Size(50, 50);
            DataTable dt = GetDemoData(1);
            UltraFormattedLinkLabel c;
            foreach (DataRow row in dt.Rows)
            {
                c = new UltraFormattedLinkLabel();
                c.Text = string.Format(row[0] + Environment.NewLine + Environment.NewLine + string.Format("{0:P2}", row[1]));
                c.BorderStyle = Infragistics.Win.UIElementBorderStyle.Solid;
                c.Appearance.BorderColor = Color.Black;
                c.Appearance.BackColor = BackColorFromValue((double)row[1]);
                this.panel1.Controls.Add(c);
                this.ultraFlowLayoutManager1.SetPreferredSize(c, preferredSize);
            }
        }

        private Color BackColorFromValue(double val)
        {
            int alphaAdjusted = (int)(255 * Math.Abs(val));
            if (val > 0d)
            {
                return Color.FromArgb(alphaAdjusted, 0, 255, 0);
            }
            if (val < 0d)
            {
                return Color.FromArgb(alphaAdjusted, 255, 0, 0);
            }

            return Color.White;
        }

        private DataTable GetDemoData(int numberOfValues)
        {
            if (numberOfValues <= 0)
            {
                throw new ArgumentException("numberOfValues needs to be greater than 0.", "numberofValues");
            }

            DataTable dt = new DataTable();
            dt.Columns.Add("Symbol", typeof(string));
            for (int i = 0; i < numberOfValues; i++)
            {
                dt.Columns.Add("Value" + (i + 1), typeof(double));
            }

            DataRow dr;
            for (int i = 0; i < 36; i++)
            {
                dr = dt.NewRow();
                dr[0] = GenerateSymbol();
                for (int j = numberOfValues; j > 0; j--)
                {
                    dr[j] = rand.NextDouble() * (i % 2 == 0 ? 1 : -1);
                }

                dt.Rows.Add(dr);
            }
            return dt;
        }

        private string GenerateSymbol()
        {
            return string.Empty + (Char)rand.Next(65, 91) + (Char)rand.Next(65, 91) + (Char)rand.Next(65, 91);
        }
    }
}
